==> evolution-kolab-3.4.1.tar.xz: evolution-kolab-3.4.1/src/libekolabutil/kolab-util-cal-freebusy.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/***************************************************************************
 *            kolab-util-cal-freebusy.h
 *
 *  Tue Aug  3 15:10:03 2010
 *  Copyright  2010  Christian Hilberg
 *  <hilberg@kernelconcepts.de>
 ****************************************************************************/

/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */
 
/*----------------------------------------------------------------------------*/

#ifndef _KOLAB_UTIL_CAL_FREEBUSY_H_
#define _KOLAB_UTIL_CAL_FREEBUSY_H_

/*----------------------------------------------------------------------------*/

#include <glib.h>

#include <libecal/e-cal-component.h>

#include <libekolabconv/main/src/kolab-conv.h>

#include "kolab-util-http.h"


/*----------------------------------------------------------------------------*/

/*
 * Utility functions for the calendar backend --
 * free/busy access
 */

ECalComponent *kolab_cal_util_fb_new_ecalcomp_from_request (KolabUtilHttpJob*, Kolab_conv_freebusy_type, GError**);
void kolab_cal_util_fb_ecalcomp_free (ECalComponent*);

/*----------------------------------------------------------------------------*/

#endif /* _KOLAB_UTIL_CAL_FREEBUSY_H_ */

/*----------------------------------------------------------------------------*/

==> evolution-kolab-3.6.4.tar.xz: evolution-kolab-3.6.4/src/libekolabutil/kolab-util-cal-freebusy.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
/***************************************************************************
 *            kolab-util-cal-freebusy.h
 *
 *  Tue Aug  3 15:10:03 2010
 *  Copyright  2010  Christian Hilberg
 *  <hilberg@kernelconcepts.de>
 ****************************************************************************/

/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */

/*----------------------------------------------------------------------------*/

#ifndef _KOLAB_UTIL_CAL_FREEBUSY_H_
#define _KOLAB_UTIL_CAL_FREEBUSY_H_

/*----------------------------------------------------------------------------*/

#include <glib.h>

#include <libecal/libecal.h>

#include <libekolabconv/main/src/kolab-conv.h>

#include "kolab-util-http.h"


/*----------------------------------------------------------------------------*/

/*
 * Utility functions for the calendar backend --
 * free/busy access
 */

ECalComponent *kolab_cal_util_fb_new_ecalcomp_from_request (KolabUtilHttpJob*, Kolab_conv_freebusy_type, GError**);
void kolab_cal_util_fb_ecalcomp_free (ECalComponent*);

/*----------------------------------------------------------------------------*/

#endif /* _KOLAB_UTIL_CAL_FREEBUSY_H_ */

/*----------------------------------------------------------------------------*/
